@@ -13,15 +13,11 @@ char *get_data_dir(void) {
   char buf[4096];
 
   buf[sizeof(buf) - 1] = 0;
-  // Where are the images datafile?
-  // default: ./data
-  // second alternative: ROCK_DODGERS_DATADIR
-  // final alternative: @datadir@/@PACKAGENAME@
   strcpy(buf, "./data");
   if(missing(buf)) {
     char *env;
 
-    env = getenv("ROCK_DODGERS_DATA");
+    env = getenv("ROCKDODGER_DATADIR");
     if(env != NULL) {
       strncpy(buf, env, sizeof(buf) - 1);
       if(missing(buf)) {
@@ -85,8 +81,13 @@ SDL_Surface *load_image(const char *fname, short kr, short kg, short kb) {
 int missing(const char *dirname) {
   struct stat buf;
 
-  lstat(dirname, &buf);
-  return (!S_ISDIR(buf.st_mode));
+  if(lstat(dirname, &buf) == 0) {
+    return (!S_ISDIR(buf.st_mode));
+  }
+#ifdef DEBUG
+  perror("missing()");
+#endif
+  return 1;
 }
 
 
