@@ -9,8 +9,10 @@
 void dead_pause();
 
 /*! \brief handle state changes due to timeout
+ *
+ * \param infoscreen_enabled = 1 if info screen should be displayed, zero if not
  */
-void handle_state_timeout();
+void handle_state_timeout(int infoscreen_enabled);
 
 /* \brief toggle game pause status
  *
