@@ -10,14 +10,14 @@
 
 // High score table
 struct highscore high[MAXIMUM_HIGH_SCORE_ENTRIES] = {
-  {13000,"Pad",2,0},
-  {12500,"Pad",2,0},
-  {6500,"RPK",1,0},
-  {5000,"RPK",1,0},
-  {3000,"Pad",1,0},
-  {2500,"RPK",1,0},
-  {2000,"Pad",1,0},
-  {1500,"RPK",1,0}
+  {13000, "Pad", 2, 0},
+  {12500, "Pad", 2, 0},
+  {6500, "RPK", 1, 0},
+  {5000, "RPK", 1, 0},
+  {3000, "Pad", 1, 0},
+  {2500, "RPK", 1, 0},
+  {2000, "Pad", 1, 0},
+  {1500, "RPK", 1, 0}
 };
 
 long score = 0;
@@ -39,6 +39,7 @@ FILE *hs_fopen(const char *mode) {
     umask(0117);
     snprintf(s, sizeof(s) - 1, "%s/.rockdodger_high", getenv("HOME"));
     if((f = fopen(s, mode)) == NULL) {
+      perror(s);
       fprintf(stderr, "Could not open highscore file '%s', mode '%s'!\n", s,
 	      mode);
     }
@@ -58,54 +59,43 @@ void read_high_score_table() {
       printf(HIGHSCORE_HEADER_FORMAT, i);
 #endif
       if(i == HIGHSCORE_VERSION) {
-	do {
 #ifdef DEBUG
-	  char debugbuf[889];
-	  long pos = ftell(f);
-	  if(fgets(debugbuf, sizeof(debugbuf), f) == NULL) {
-	    perror("fgets in read_high_score_table()");
-	    break; //the loop
-	  }
-	  printf("next line pos=%04lX '%s'\n", pos, debugbuf);
-	  fseek(f, pos, SEEK_SET);
+	char debugbuf[889];
+	long pos = ftell(f);
+	if(fgets(debugbuf, sizeof(debugbuf), f) == NULL) {
+	  perror("fgets in read_high_score_table()");
+	}
+	printf("next line pos=%04lX '%s'\n", pos, debugbuf);
+	fseek(f, pos, SEEK_SET);
 #endif
-	  for(i = 0; i < MAXIMUM_HIGH_SCORE_ENTRIES && !giveup; ++i) {
-	    char s[1024];
-	    long int highscore;
-	    int scanret;
-	    if(high[i].allocated) {
-	      free(high[i].name);
-	      high[i].allocated = 0;
-	    }
-	    scanret = fscanf(f, "%ld %1023[^\n]", &highscore, s);
+	for(i = 0; i < MAXIMUM_HIGH_SCORE_ENTRIES && !giveup; ++i) {
+	  char s[1024];
+	  long int highscore;
+	  int scanret;
+	  if(high[i].allocated) {
+	    free(high[i].name);
+	    high[i].allocated = 0;
+	  }
+	  scanret = fscanf(f, "%ld %1023[^\n]", &highscore, s);
 #ifdef DEBUG
-	    printf("i=%d scanret=%d pos=%04lX highscore=%5ld '%s'\n", i, scanret, ftell(f), highscore, s);
+	  printf("i=%d scanret=%d pos=%04lX highscore=%5ld '%s'\n", i, scanret, ftell(f), highscore, s);
 #endif
-	    switch (scanret) {
-	    case 2:
-	      high[i].name = strdup(s);
-	      high[i].score = highscore;
-	      high[i].allocated = 1;
-	      break;
-	    case 1:
-	      high[i].name = "";
-	      high[i].score = highscore;
-	      high[i].allocated = 0;
-	      break;
-	    default:
-	      giveup = 1;
-	      break;
-	    }
+	  switch (scanret) {
+	  case 2:
+	    high[i].name = strdup(s);
+	    high[i].score = highscore;
+	    high[i].allocated = 1;
+	    break;
+	  case 1:
+	    high[i].name = "";
+	    high[i].score = highscore;
+	    high[i].allocated = 0;
+	    break;
+	  default:
+	    giveup = 1;
+	    break;
 	  }
-	  /* This is needed as the 'scanret = fscanf(f, "%ld
-	     %1023[^\n]", &highscore, s)' reads until a LF is
-	     encountered. *But* this LF is *not* consumed so, in order
-	     of the rest of the loop ('i = fscanf(f,
-	     HIGHSCORE_EDITION_FORMAT, &edition);') to work correctly,
-	     we have to skip the LF. Stupid of me to forget this and
-	     to do a lot of debugging and debug print output. Phew! */
-	  i = fgetc(f);
-	} while(i != EOF);
+	}
       }
     }
     fclose(f);
