@@ -18,7 +18,7 @@ struct highscore {
 };
 
 //! high is a an array of highscore structs.
-extern struct highscore high[EDITION_MAXIMUM_EDITION][MAXIMUM_HIGH_SCORE_ENTRIES];
+extern struct highscore high[MAXIMUM_HIGH_SCORE_ENTRIES];
 
 extern long score;		//!< The current score.
 extern int scorerank;		//!< minus one means no scorerank, we are not worthy
