@@ -44,8 +44,7 @@ char intro_default_text[] = "Exploding Rock Productions presents \"Rock Dodger\"
   "Press any key to continue!    "
   "       %s        "
   "Credits: Coding by Paul Holt, RPK. Music by Jack Beatmaster, Roz, Strobo, zake. Gfx: Paul Holt, RPK. Font: ripped from lib-sge.   "
-  "  A little bit of history: In 1984 Paul Holt programmed the first version of the game in his computer science class. The game was later (in 2001) ported to Linux and SDL. In December 2010 I (RPK) joined the project and started cleaning up the code and added the eye blink to the greeblies. In 2012 we moved the main development site to http://code.google.com/p/rockdodger/. And here we are... Enjoy!       "
-  "Special Greetings go to my mom, I will miss you always...          "
+  "  A little bit of history: In 1984 Paul Holt programmed the first version of the game in his computer science class. The game was later (in 2001) ported to Linux and SDL. In December 2010 I (RPK) joined the project and started cleaning up the code and added the eye blink to the greeblies. In 2015 we moved the main development site to https://bitbucket.org/rpkrawczyk/rockdodger. And here we are... Enjoy!       "
   ;
 static char txtbuf[8001];
 
@@ -127,6 +126,33 @@ struct rockintro *init_intro(SDL_Surface *target, uiff_ctx_t *iff) {
 }
 
 
+void fld_logo(struct rockintro *intro, SDL_Surface *target, float movementrate) {
+  int rastline;
+  SDL_Surface *lsurf = intro->intro_image;
+  SDL_Rect r = { (target->w - 640) / 2, 0, 0, 0 };
+  SDL_Rect s = { 0, 0, lsurf->w, 1};
+
+  if(intro->fld_amplitude <= 0) {
+    s.h = lsurf->h;
+    SDL_BlitSurface(intro->intro_image, NULL, target, &r);
+  } else {
+    float phi = intro->fld_logophase;
+    float tline = intro->fld_logo_wagging_amplitude * sinf(phi);
+    float camp = intro->fld_amplitude; // cosine amplitude
+
+    intro->fld_last_topline = (int)tline;
+    for(rastline = 0; rastline < lsurf->h; ++rastline) {
+      s.y = rastline;
+      r.y = tline;
+      SDL_BlitSurface(intro->intro_image, &s, target, &r);
+      tline += 1 + camp + cosf(phi) * camp;
+      phi += 1.0 / 200.0 * M_PI;
+    }
+    intro->fld_logophase += movementrate / 11;
+  }
+}
+
+
 void update_and_draw_intro(struct rockintro *intro, SDL_Surface *target, float movementrate) {
   int i, j;
   float z_positions[NUM_COPPERBARS];
@@ -146,9 +172,7 @@ void update_and_draw_intro(struct rockintro *intro, SDL_Surface *target, float m
     SDL_BlitSurface(intro->copperbars[minimum], NULL, target, &r);
     z_positions[minimum] = 666;
   }
-  r.x = (target->w - 640) / 2;
-  r.y = 0;
-  SDL_BlitSurface(intro->intro_image, NULL, target, &r);
+  fld_logo(intro, target, movementrate);
   update_and_draw_scroller(intro->scroller, target, movementrate * 1.412);
   draw_sparkles(target);
   update_sparkles(target);
@@ -175,6 +199,7 @@ void play_intro(int force, int oss_sound_flag, uiff_ctx_t iff) {
   int running = 1;
   SDL_Surface *surf_screen = SDL_GetVideoSurface();
   short deltah, heading = 0;
+  float *fp;
 
   if(force == 0) {
     switch(opt_intro) {
@@ -213,7 +238,7 @@ void play_intro(int force, int oss_sound_flag, uiff_ctx_t iff) {
     }
     SDL_FillRect(surf_screen, NULL, SDL_MapRGB(surf_screen->format, 0, 0, 0));
     update_and_draw_intro(intro, surf_screen, movementrate);
-    state = (last_ticks / 0x1BC6) % 9;
+    state = (last_ticks / 0x1BC6) % 10;
     if(state != last_state) {
       switch(state) {
       case 6:
@@ -240,9 +265,9 @@ void play_intro(int force, int oss_sound_flag, uiff_ctx_t iff) {
     draw_engine_dots(surf_screen);
     SDL_UnlockSurface(surf_screen);
     switch(state) {
-    case 6:
     case 5:
     case 1:
+    case 6:
       draw_ship(surf_screen);
       create_engine_dots(220);
       xship += movementrate * 6.08 * surf_screen->w / 800.0; //Ship should have the same speed, regardless of the screen size.
@@ -263,10 +288,17 @@ void play_intro(int force, int oss_sound_flag, uiff_ctx_t iff) {
     case 7:
     case 8:
       deltah = (surf_screen->w - 640) / 2;
-      create_plumedots(7, 168 + deltah, 47, -heading, 4, 8);
-      create_plumedots(7, surf_screen->w - 158 - deltah, 47, heading, 4, 8);
+      i = intro->fld_last_topline;
+      create_plumedots(7, 168 + deltah, i + 47, -heading, 4, 8);
+      create_plumedots(7, surf_screen->w - 158 - deltah, i + 47, heading, 4, 8);
       heading += 2;
       break;
+    case 9:
+      fp = &intro->fld_logo_wagging_amplitude;
+      if(*fp < 20) *fp += movementrate / 61.51;
+      fp = &intro->fld_amplitude;
+      if(*fp < 1.0 / 5.014847583) *fp += movementrate / 77.8111472142;
+      break;
     }
     SDL_Flip(surf_screen);
   }
