@@ -100,7 +100,7 @@ int rockfree_space_max = 0;
 char *sequence[] = {
   "Rock Dodger",
   "Press SPACE to start!",
-  "http://code.google.com/p/rockdodger/",
+  "http://bitbucket.org/rpkrawczyk/rockdodger/",
   "Arrow keys move the ship.",
   "Press S for shield and D for laser.",
   "If you need a pause press P.",
@@ -156,7 +156,9 @@ int restart_game() {
     "A place in the hall of fame has been reserved for you!",
     "Amazing performance! You earned a high score.",
     "Unbelievable, do you do anything besides playing this game?",
-    "Oh, come on... Admit it... You cheated, did you not?"
+    "Oh, come on... Admit it... You cheated, did you not?",
+    /* Do you remember Uridium? */
+    "You have amassed a great score!"
   };
   const int num_of_txts = sizeof(txts) / sizeof(const char *);
   char buf[160];
@@ -375,7 +377,7 @@ int init() {
   NULL_GURU(init_infoscreen(*iff_ctx), GM_SS_Misc | GM_GE_OpenDev | GURU_SEC_infoscreen, &init_infoscreen);
   NULL_ERROR(init_blubats(*iff_ctx));
   NULL_ERROR(init_powerup());
-  NULL_ERROR(mood_icon = init_mood_item());
+  NULL_ERROR(mood_icon = init_mood_item(*iff_ctx));
   // Load all our lovely rocks
   NULL_ERROR(init_rocks());
   NULL_ERROR(init_greeblies());
@@ -928,8 +930,10 @@ int gameloop() {
       update_yellifishs(yellifishs, xship, yship - 87.8228228);
       update_sparkles(surf_screen);
       break;
-    case INFO_SCREEN:
     case GAME_OVER:
+      if(keystate[SDLK_ESCAPE]) play_sound(SAMPLE_XBAD);
+      //DANGER! Falls through!
+    case INFO_SCREEN:
     case HIGH_SCORE_DISPLAY:
     case HIGH_SCORE_ENTRY:
       // Move all the rocks
@@ -964,7 +968,7 @@ int gameloop() {
 
     if(keystate[SDLK_SPACE]
        && (state == HIGH_SCORE_DISPLAY || state == TITLE_PAGE
-	   || state == DEMO)) {
+	   || state == DEMO || state == INFO_SCREEN)) {
       ready_for_takeoff();
     }
 
@@ -1032,7 +1036,7 @@ int main(int argc, char **argv) {
   assert(RD_VIDEO_BPP == 8 * sizeof(RD_VIDEO_TYPE));
   oss_sound_flag = 1;
   load_setup();
-  while((x = getopt(argc, argv, "P:Ifwskhx:y:")) >= 0)
+  while((x = getopt(argc, argv, "P:Ifwskh?x:y:")) >= 0)
     switch (x) {
     case 'P':
       rockiff_name = strdup(optarg);
@@ -1060,6 +1064,7 @@ int main(int argc, char **argv) {
     case 'w':
       opt_fullscreen = 0;
       break;
+    case '?':
     case 'h':
       printf("Rock Dodgers\n"
 	     "  -h This help message\n"
@@ -1068,7 +1073,10 @@ int main(int argc, char **argv) {
 	     "  -x xsize\n"
 	     "  -y ysize\n"
 	     "  -k Keyboard only - disable joystick\n"
-	     "  -s Silent mode (no OSS sound)\n");
+	     "  -s Silent mode (no sound)\n"
+	     "  -P parameter file\n"
+	     "  -I force intro\n"
+	     );
       exit(0);
       break;
     }
