@@ -2,13 +2,14 @@
 #define __POWERUP_H__2010
 #include <SDL/SDL.h>
 #include "datafun.h"
-#include "rockdodger_globals.h"
+#include "globals.h"
 
 typedef enum powerup_types {
   POWERUP_NONE,
   POWERUP_LASER,
   POWERUP_SHIELD,
-  POWERUP_LIFE
+  POWERUP_LIFE,
+  POWERUP_MAXPOWERUP
 } powerup_types_t;
 
 //!< This structure holds all information about the powerup.
@@ -20,6 +21,15 @@ typedef struct powerup {
   float img_ctr;		//!< Counter of the current image surface
 } powerup_t;
 
+
+/*! \brief array with power surfaces
+ *
+ * Here we store all surfaces for the powerup animations. The order is
+ * the same as the powerup numbers.
+ */
+sdl_surfaces_t *surf_powerups[POWERUP_MAXPOWERUP];
+
+
 /*! \brief Get the current powerup type.
  *
  * If currently no powerup is active then this will return
